package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@(!`0````````````,`/@`!````5#(```````!``````````$#!````
M`````````$``.``+`$``&P`:``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"````````J`(````````<`````````!P``````````0`````````!````
M!````````````````````````````````````%`A````````4"$`````````
M$`````````$````%`````#``````````,``````````P````````U3D`````
M``#5.0`````````0`````````0````0`````<`````````!P`````````'``
M``````!(1P```````$A'`````````!`````````!````!@```'B[````````
M>,L```````!XRP```````*@$````````\!0`````````$`````````(````&
M````B+L```````"(RP```````(C+````````,`(````````P`@````````@`
M````````!`````0```#$`@```````,0"````````Q`(````````@````````
M`"``````````!`````````!0Y71D!````("P````````@+````````"`L```
M`````-P`````````W``````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``!XNP```````'C+````````>,L```````"(!````````(@$`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!`````!````
M1TY5```````"````!@```!(`````````P0```&,``````````````%\````D
M````````````````````'@``````````````+P```%4````<````&````&``
M````````````````````````60```````````````````!0`````````````
M````````````````````````````````````````````````````````````
M```````````6````````````````````-P`````````I````,```````````
M````+0```%H````:```````````````1````!P``````````````````````
M```T````5P```#$```!<``````````8```````````````````!;````````
M````````````*@`````````U````5@`````````)````````````````````
M`````%@````V``````````@`````````/0````````!``````````#X```!"
M`````````````````````````",`````````+@````\```!=````````````
M```7````#````````````````````$0````;````3@```#L`````````````
M```````0````$P``````````````.````$L```````````````````!0````
M0P```#D```````````````H```!B````!`````````!(````/```````````
M````,P```$<`````````,@`````````H````"P````(````A````+````%,`
M`````````````````````````````%X````?````````````````````10``
M``$`````````)0```"<```!/``````````X``````````````%(````Z````
M``````````!A```````````````_`````````"``````````````````````
M````5````````````````````$8```!!````````````````````````````
M````````````````````````````````````````````````````````2@``
M````````````````````````````````````````````````````````````
M````````````````#0``````````````$@`````````9````````````````
M`````````````````````````````````````P`````````K````````````
M`````````````````````````````````````````````$D`````````````
M`````````````````"(```````````````````````````````````!,````
M'0```````````````````"8```!1````````````````````````````````
M```````````````5````30``````````````````````````````````````
M````````!0``````````````````````````````-````$@````$````"```
M`"`0$``%0`2$*`(``("&`(""*0``"2`$"8B@&46Z!`((2`````````!)````
M2@```$L```!,````30``````````````````````````````````````````
M````3@```````````````````$\``````````````%$```!2````5```````
M``!5````5@``````````````5P```%D```!:``````````````!;````7```
M````````````70```%X```!?````8`````````!A````````````````````
M8@```````````````````-5DU'QK?YI\0T75[-EQ6!RM2^/`,V+;[:/@^TG.
MWD<MP^4_+"_%F[9NQ=\?N^.2?-%ESFVS`8MO^Z%L8.K3[PYK"4/6XT?&`;F-
M\0Y_J9R;#3J7"V>OS&8-%.*>X:<""MO-XYZ)!W#3(?_D#@``````````````
M``````````````````````!(`0``$@````````````````````````"X`0``
M$@`````````````````````````<`@``$@`````````````````````````"
M`@``$@`````````````````````````!````(```````````````````````
M```C`@``$@````````````````````````"H`@``$@``````````````````
M``````!C````$@`````````````````````````X`@``$@``````````````
M``````````#%````$@````````````````````````"0`@``$@``````````
M``````````````"(`@``$@`````````````````````````&`0``$@``````
M``````````````````!V`P``$@````````````````````````!#`0``$@``
M``````````````````````!4`@``$@````````````````````````!&`@``
M$@````````````````````````"A`@``$@````````````````````````"^
M`@``$@````````````````````````"A`0``$0``````````````````````
M```5`0``$@````````````````````````!&````$0``````````````````
M``````#I````$@````````````````````````"<````$@``````````````
M```````````C`0``$@````````````````````````#E`0``$@``````````
M```````````````3`@``$@````````````````````````#K`0``$@``````
M```````````````````*`@``$@````````````````````````!-`0``$@``
M```````````````````````Q`@``$@````````````````````````"S`0``
M$@`````````````````````````"`P``$@`````````````````````````5
M`P``(0````````````````````````!H`@``$@``````````````````````
M``#[`@``$@````````````````````````!3````$@``````````````````
M``````"Q`@``$@`````````````````````````=````(```````````````
M```````````6`P``$0````````````````````````!@`0``$@``````````
M``````````````#1`0``$@````````````````````````!9`0``$@``````
M``````````````````"N````$@`````````````````````````N`0``$@``
M``````````````````````"Z````$@````````````````````````"``0``
M$@````````````````````````"3`0``$@````````````````````````!_
M````$@````````````````````````!O`@``$@``````````````````````
M``#>````$@````````````````````````!O`0``$@``````````````````
M```````I`@``$@````````````````````````"L`0``$@``````````````
M``````````#L`@``$@````````````````````````#%`@``$@``````````
M``````````````!Q````$@````````````````````````"+````$@``````
M``````````````````#T`@``$@`````````````````````````_`@``$@``
M``````````````````````#W````$@````````````````````````#5````
M$@````````````````````````!]`@``$@`````````````````````````4
M`P``$0````````````````````````#]`0``$@``````````````````````
M``#)`0``$@````````````````````````!:`@``$@``````````````````
M```````L````(`````````````````````````!-`@``$@``````````````
M``````````":`@``$0````````````````````````#>`@``$@``````````
M``````````````!7!```$@`.`/!D````````J`,````````/`P``$@`.`%`P
M`````````0(```````"+`P``$``7`"#0```````````````````6!```$``8
M`"#0``````````````````#%`P``$0`0``!P````````!`````````"^`P``
M$@`.`%0R```````````````````)!```$@`.`,!2````````V04```````"K
M`P``$@`.`&!:````````@PH````````B!```$@`.`)!.````````-0``````
M``!3`P``$@`.`,!/````````!@````````!_`P``$@`.`*!H````````9@``
M```````$!```$``8`&C@``````````````````#/`@``(@``````````````
M``````````!)!```$@`.`*!8````````3@`````````W!```$@`.`!!9````
M````1`$```````!-`P``$@`/`,QI``````````````````"X`P``$``7``#0
M``````````````````"2`P``$@`.`*!1````````)``````````D!```$@`+
M```P``````````````````!D`P``$@`.`/!8````````'P````````"Z`P``
M(``7``#0``````````````````"?`P``$@`.`-!1````````[`````````!#
M`P``$@`.`#!I`````````@````````#4`P``$@`.`"!/````````F0``````
M``#J`P``$@`.`$!I````````B0````````#Z`P``$0`7`!C0````````"```
M```````J!```$@`.`-!/````````SP$`````````7TE435]D97)E9VES=&5R
M5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L
M;VYE5&%B;&4`4$Q?9&]?=6YD=6UP`%!E<FQ?9W9?9F5T8VAP=@!097)L7V%V
M7W-H:69T`%!E<FQ?879?9F5T8V@`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?
M;&]C:P!097)L7W-V7S)P=E]F;&%G<P!097)L7V=E=%]S=@!097)L7VYE=UA3
M`&)O;W1?1'EN84QO861E<@!P97)L7W)U;@!P97)L7W!A<G-E`%!E<FQ?<W9?
M<V5T<'8`4&5R;%]S=E]S971P=FX`<&5R;%]C;VYS=')U8W0`<&5R;%]D97-T
M<G5C=`!P97)L7V%L;&]C`%!E<FQ?8W)O86M?;F]C;VYT97AT`'!E<FQ?9G)E
M90!097)L7W-A9F5S>7-M86QL;V,`4&5R;%]S>7-?:6YI=#,`4&5R;%]N97=8
M4U]F;&%G<P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S>7-?=&5R;0!03%]T
M:')?:V5Y`&]P96XV-`!R96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!P
M=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`%]?<F5G:7-T97)?871F;W)K`&5X
M:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!U;FQI;FL`;6MD:7(`<F5A
M;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER
M`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V
M-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?
M;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?
M<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R
M=%]M86EN`%]?96YV:7)O;@!L:6)P97)L+G-O`&QI8G!T:')E860N<V\N,`!L
M:6)C+G-O+C8`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T
M7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7V5D871A`'!A
M<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T
M87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI
M8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`<&%R7VEN:71?96YV`%]?8G-S
M7W-T87)T`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H
M`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N
M,BXU`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`"]O<'0O8V]N9&$O8V]N9&$M
M8FQD+W!E<FPM<&%R+7!A8VME<E\Q-C0U-SDX-C,W,C0Y+U]H7V5N=E]P;&%C
M96AO;&1?<&QA8V5H;VQD7W!L86-E:&]L9%]P;&%C96AO;&1?<&QA8V5H;VQD
M7W!L86-E:&]L9%]P;&%C96AO;&1?<&QA8V5H;VQD7W!L86-E:&]L9%]P;&%C
M96AO;&1?<&QA8V5H;VQD7W!L86-E:&]L9%]P;&%C96AO;&1?<&QA8V5H;VQD
M7W!L86-E:&]L9%]P;&%C96AO;&1?<&QA8V5H;VQD7W!L86-E:&]L9%]P;&%C
M96AO;&1?<&QA8V5H;R]B:6XO+BXO;&EB+W!E<FPU+S4N,S(O8V]R95]P97)L
M+T-/4D4Z+V]P="]C;VYD82]C;VYD82UB;&0O<&5R;"UP87(M<&%C:V5R7S$V
M-#4W.3@V,S<R-#DO7VA?96YV7W!L86-E:&]L9%]P;&%C96AO;&1?<&QA8V5H
M;VQD7W!L86-E:&]L9%]P;&%C96AO;&1?<&QA8V5H;VQD7W!L86-E:&]L9%]P
M;&%C96AO;&1?<&QA8V5H;VQD7W!L86-E:&]L9%]P;&%C96AO;&1?<&QA8V5H
M;VQD7W!L86-E:&]L9%]P;&%C96AO;&1?<&QA8V5H;VQD7W!L86-E:&]L9%]P
M;&%C96AO;&1?<&QA8V5H;VQD7W!L86-E:&]L9%]P;&%C96AO+VQI8CHO;W!T
M+V-O;F1A+V-O;F1A+6)L9"]P97)L+7!A<BUP86-K97)?,38T-3<Y.#8S-S(T
M.2]?8G5I;&1?96YV+VQI8@````(``P`"``(````"``(````"`````@`"````
M`@````(``@`"``(``````````````````P`"``0``@````(``P`"``(``@`"
M````!0````(````#``(`````````````````!0```````@`#``(``@``````
M`@`"```````"``(``@`#``4````"``(`!0`!``$``0`!``$``0`!``$``0`!
M``$``0`"``$``0`!``$``0`!``$``0`!``$``0`!``$``0`````````!``$`
M*0,``!`````@````=1II"0```P!M!`````````$``P`Y`P``$`````````!T
M&6D)```%`'D$```0````<AEI"0``!`"%!```$````'4::0D```(`;00`````
M``!XRP````````@`````````)#,```````"`RP````````@`````````\C(`
M```````(T`````````@`````````"-`````````8T`````````@`````````
M"',```````#@S0````````8````!``````````````#HS0````````8````"
M``````````````#PS0````````8````#``````````````#XS0````````8`
M```$````````````````S@````````8````%```````````````(S@``````
M``8````&```````````````0S@````````8````'```````````````8S@``
M``````8````(```````````````@S@````````8````)```````````````H
MS@````````8````*```````````````PS@````````8````+````````````
M```XS@````````8````,``````````````!`S@````````8````-````````
M``````!(S@````````8````.``````````````!0S@````````8````/````
M``````````!8S@````````8````0``````````````!@S@````````8````1
M``````````````!HS@````````8````2``````````````!PS@````````8`
M```3``````````````!XS@````````8````4``````````````"`S@``````
M``8````5``````````````"(S@````````8````6``````````````"0S@``
M``````8````7``````````````"8S@````````8````8``````````````"@
MS@````````8````9``````````````"HS@````````8````:````````````
M``"PS@````````8````;``````````````"XS@````````8````=````````
M``````#`S@````````8````>``````````````#(S@````````8````?````
M``````````#0S@````````8````@``````````````#8S@````````8````C
M``````````````#@S@````````8````D``````````````#HS@````````8`
M```E``````````````#PS@````````8````F``````````````#XS@``````
M``8````G````````````````SP````````8````H```````````````(SP``
M``````8````I```````````````0SP````````8````J```````````````8
MSP````````8````K```````````````@SP````````8````L````````````
M```HSP````````8````M```````````````PSP````````8````N````````
M```````XSP````````8````O``````````````!`SP````````8````P````
M``````````!(SP````````8````Q``````````````!0SP````````8````R
M``````````````!8SP````````8````S``````````````!@SP````````8`
M```T``````````````!HSP````````8````U``````````````!PSP``````
M``8````V``````````````!XSP````````8````W``````````````"`SP``
M``````8````X``````````````"(SP````````8````Y``````````````"0
MSP````````8````Z``````````````"8SP````````8````[````````````
M``"@SP````````8````\``````````````"HSP````````8````]````````
M``````"PSP````````8````^``````````````"XSP````````8````_````
M``````````#`SP````````8```!!``````````````#(SP````````8```!"
M``````````````#0SP````````8```!#``````````````#8SP````````8`
M``!$``````````````#@SP````````8```!4``````````````#HSP``````
M``8```!%``````````````#PSP````````8```!&``````````````#XSP``
M``````8```!'``````````````#0S0````````<````<``````````````#8
MS0````````<````A````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````2(/L".AW`@``2(/$",,``/\UJIT``/\EK)T```\?0`#_):J=``!H````
M`.G@_____R6BG0``:`$```#IT/____\EFI\``&:0``````````!!5%5(@^PX
MB7PD'$B-?"0<2(ET)!!(C70D$$B)5"0(2(U4)`C_%8Z>``!(BS6WG@``2(L]
M")\``$B)\F?H?S@``$B+!?"=``"`.``/A"`!``!,BR70G0``08L\)/\57IX`
M`$&+/"2`B#H$```"_Q5-G@``@(@Z!````8M$)!R->`5(8_](P><#_Q7BG0``
M2(M\)!!,8T0D',<%7J\```0```!(B<%(B05,KP``2(L'38G!2(D!2(T%[D``
M`$B)00A(C04!GP``2(L`2(E!$$B-!=A```!(B4$8N`$```!!@_@!?AH/'T``
M2(LTQXU0`TC_P$ACTDB)--%,.<!UZD&-40-(BST'KP``13'`2(TU;1T``$AC
MPDC'!,$`````_Q7DG0``08G$A<!T?DB-;"0L2(L]V:X``/\5\YP``#'`2(GN
M2(T]"C\``.AR%P``2(7`=&M(BSVVK@``_Q6@G```_Q6*G0``2(/$.$2)X%U!
M7,/_%=F<``!(B062K@``2(G'2(7`='#_%62<``!,BR65G```08L\)/\5(YT`
M`,:`Z0D```#IK_[__TB+/6"N``#_%:J=``!!B<3I;?___TB+/4.N``!(A?]T
M"&?H@#8``.N!2(T]+SX``$B)[NC?%@``2(D%(*X``$B)QTB%P`^$7____^O4
MOP$```#_%6^=```/'P`Q[4F)T5Y(B>)(@^3P4%1,C07&-@``2(T-SS8``$B-
M/=C]___HL_W___20D$B#[`A(BP5MG```2(7`=`+_T$B#Q`C#2(T]@IT``$B-
M!7N=``!(.?AT#DB+!4^;``!(A<!T`O_@PTB-/6"=``!(C359G0``N0(```!(
M*?Y(P?X#2(GP2)E(]_E(B<9(A<!T#DB+!>Z<``!(A<!T`O_@PX`])YT```!U
M*%5(@SW<G````$B)Y70,2(L]^)P``.@K_?__Z'W____&!?^<```!7</#ZY-F
M+@\?A```````05=,C4\X059!54%455-(@>P0`@``3(U$)(A,C50D"$R)QF8/
M'T0``$&+`4F+"4B#QA!)@\$(#\B)P$B)RDB)1O!(B<A(P>H@2,'H*$C!Z3@E
M`/\``$@)R$B)T4C!X@A(P>$8@>(``/\`B<E("<A("=!(B4;X3#G6=:YF#V\5
M;GP``$B-1"3P28V0:`(``&:09@]O0*CS#V\(2(/`$&8/[TC(9@_O0(AF#^_!
M9@]OR&8/<]`?9@]S\0%F#^O!9@_;P@\I0`A(.<)UQDR+#TR+7Q!(BW<@2(M?
M&$R)R$R)RDB+;PA(P>H;2,'@!4@)T`-$)(B-E#"9>8):3(G82(MT))!(,=A(
M(>A(C;0SF7F"6D@QV$2-%`)(B>I(B>A(P>@"2,'B'DV)T$@)PDR)V$G!Z!N)
MT4@QR$PAR$PQV$@!\$R)UDC!Y@5,"<9$C30P3(G.3(G(2,'F'DC!Z`)-B?!(
M"?!(BW0DF$G!Z!M(,<)!B<5,(=))C;0SF7F"6D@QRD@!\DR)]DC!Y@5,"<9$
MC00R3(G62<'J`DB+5"2@2,'F'DP)UDB-E!&9>8):3(G!2#'P08GT3"'P3#'H
M2,'I&T@!T$R)PDC!X@5("<I,B?%)P>X"2,'A'D2-%!!(B?!(BU0DJ$P)\4R)
MUD@QR$F-E!69>8):2,'N&T&)SDPAP$PQX$@!T$R)TDC!X@5("?)$C2P03(G"
M2<'H`DB+1"2P2,'B'DR)[DP)PDF-A`29>8):2,'N&T@QT4&)T$PAT4PQ\4@!
MP4R)Z$C!X`5("?!$C20!3(G02<'J`DB+3"2X2,'@'DR)YDP)T$F-C`Z9>8):
M2#'"08G"3"'J3#'"2`'*3(GA2,'A!4C![AM("?%,B>Y)P>T"2,'F'D2--`I(
MBU0DP$P)[DR)\4@Q\$F-E!"9>8):2,'I&T&)]4PAX$PQT$@!T$R)\DC!X@5(
M"<I,B>%)P>P"2,'A'D2-!!!(B?!(BU0DR$P)X4R)QD@QR$F-E!*9>8):2,'N
M&T&)S$PA\$PQZ$@!T$R)PDC!X@5("?)$C1003(GR2<'N`DB+1"302,'B'DR)
MUDP)\DF-A`69>8):2,'N&T@QT4&)UDPAP4PQX4@!P4R)T$C!X`5("?!$C2P!
M3(G`2<'H`DB+3"382,'@'DR)[DP)P$F-C`R9>8):2,'N&T@QPD&)P$PATDPQ
M\D@!RDR)Z4C!X05("?%,B=9)P>H"2,'F'D2-)`I(BU0DX$P)UDR)X4@Q\$F-
ME!:9>8):2,'I&T&)\DPAZ$PQP$@!T$R)XDC!X@5("<I,B>E)P>T"2,'A'D2-
M-!!(B?!(BU0DZ$P)Z4R)]D@QR$F-E!"9>8):2,'N&T&)S4PAX$PQT$@!T$R)
M\DC!X@5("?)$C0003(GB2(M$)/!(P>(>2<'L`DR)QDP)XDF-A`*9>8):2,'N
M&T@QT4&)U$PA\4PQZ4@!P4R)P$C!X`5("?!$C10!3(GP2<'N`DB+3"3X2,'@
M'DR)UDP)\$F-C`V9>8):2,'N&T@QPD&)QDPAPDPQXD@!RDR)T4C!X05("?%,
MB<9)P>@"2,'F'D2-+`I(BQ0D3`G&3(GI2#'P28V4%)EY@EI(P>D;08GP3"'0
M3#'P2`'03(GJ2,'B!4@)RDR)T4G!Z@)(P>$>1(TD$$B)\$B+5"0(3`G13(GF
M2#'(28V4%IEY@EI(P>X;08G*3"'H3#'`2`'03(GB2,'B!4@)\D2--!!,B>I)
MP>T"2(M$)!!(P>(>3(GV3`GJ28V$`)EY@EI(P>X;2#'108G53"'A3#'12`'!
M3(GP2,'@!4@)\$2-!`%,B>!)P>P"2(M,)!A(P>`>3`G@28V,"IEY@EI-B<)(
M,<))P>H;B<9,(?),,>I(`<I,B<%(P>$%3`G138GR2<'N`DG!XAZ)R4T)\D@!
MRDB+3"0@3#'008G43"'`28V,#9EY@EI-B>5(,?!)P>T;2`'(3(GA2,'A!4P)
MZ8G)2`'(3(G!2<'H`DC!X1Y!B<5,"<%-B=!%B=),`U0D,$DQR$0QPDR+1"0H
M3HV$!J'KV6Y,B>Y)`=!,B>I(P>X;2,'B!4@)\HG220'03(GB2<'L`DC!XAY$
MB<9,">))B<R)R4@#3"0X23'41#'@28GT38V4`J'KV6Y(B?!)P>P;2,'@!4P)
MX(G`20'"3(GH2<'M`DC!X!Y%B=1,">A)B=6)TDDQQ44QZ$V)Y4@#5"1`3HV$
M`:'KV6Y,B>%)P>T;2,'A!4P)Z8G)3`'!28GP2,'N`DG!X!Y!B<U)"?!(B<:)
MP$@#1"1(3#'&03'R2HVT$J'KV6Y,B>I-B>I)P>H;2,'B!4P)THG22`'R3(GF
M2<'L`DC!YAY!B=),">9-B<1%B<!,`T0D4$DQ]$0QX4V)U$B-C`BAZ]EN3(G0
M2<'L&TC!X`5,">")P$@!R$R)Z4G![0)(P>$>08G$3`GI28GUB?9),<U$,>I-
MB>5-C800H>O9;DR)XDC!X@5)P>T;2`-T)%A,">J)TDD!T$R)TDG!Z@)(P>(>
M18G%3`G228G*B<E(`TPD8$DQTD0QT$V)ZDB-M`:AZ]EN3(GH2<'J&TC!X`5,
M"=")P$@!QDR)X$G![`)(P>`>08GR3`G@28G4B=)(`U0D:$DQQ$4QX$V)U$Z-
MA`&AZ]EN3(G12<'L&TC!X05,">&)R4P!P4V)Z$G![0))P>`>08G,30GH28G%
MB<!-,<5$,>Y-B>5(C;0RH>O9;DR)XDG![1M(P>(%3`GJB=)(`?),B=9)P>H"
M2`-$)'!(P>8>08G53`G638G"18G`3`-$)'A),?)$,=%-B>I(C8P(H>O9;DR)
MZ$G!ZAM(P>`%3`G0B<!(`<A,B>%)P>P"2,'A'D&)PDP)X4F)](GV2`.T)(``
M``!),<Q$,>)-B=1-C800H>O9;DR)TDG![!M(P>(%3`GBB=))`=!,B>I)P>T"
M2,'B'D6)Q$P)ZDF)S8G)23'51#'H38GE2(VT!J'KV6Y,B>!)P>T;2,'@!4P)
MZ(G`2`'&3(G02,'@'DG!Z@)!B?5(`XPDB````$P)T$F)THG22`.4))````!)
M,<)%,=!-B>I.C80!H>O9;DR)Z4G!ZAM(P>$%3`G1B<E,`<%-B>!)P>P"2<'@
M'D&)RDT)X$F)Q(G`2`.$))@```!-,<1$,>9-B=1(C;0RH>O9;DR)TDG![!M(
MP>(%3`GBB=)(`?),B>Y)P>T"2,'F'D&)U$P)[DV)Q46)P$DQ]40QZ4V)Y4B-
MC`BAZ]EN3(G@2<'M&TC!X`5,">B)P$@!R$R)T4G!Z@)(P>$>08G%3`G128GR
M3`.$)*````")]DDQRD@#M"2H````1#'238VT$*'KV6Y,B>I-B>A)P>@;2,'B
M!4P)PDF)R(G)2`.,)+````")TDD!UDR)XDG![`)(P>(>18GR3`GB23'01#'`
M3(VD!J'KV6Y,B=!,B=9(P>X;2,'@!4@)\$B)UHG22`.4)+@```")P$D!Q$R)
MZ$G![0)(P>`>18G@3`GH2#'&03'V3(G&3HVL,:'KV6Y,B<%(P>X;2,'A!4@)
M\8G)20'-3(G12<'J`DC!X1Y$B>Y,"=%)B<*)P$DQRD4QU$@#A"3`````3HV4
M(J'KV6Y(B?))B?1)P>P;2,'B!4P)XDV)Q$G!Z`))P>0>00'230G$28G(B<E-
M,>!$B>)%,<5.C80HH>O9;DR)T$V)U4G![1M(P>`%3`GH3(NL),@```!%C30`
M28GP2,'N`DR)X$G!X!Y)"?!$B<9,"<!,(=!)(?1)"<2XW+P;CTD!Q4P!Z4V)
M]4P!X4V)]$G![1M)P>0%30GL00',3(G12<'J`DC!X1Y,"=%)"<A)B<U!B<I-
M(?!)(?5-">A,BZPDT````$D!Q4P!ZDV)Y4D!T$R)XDG![1M(P>(%3`GJ18TL
M$$R)\DG![@)(P>(>3`GR28G.08G020G632'F3"'!3`GQ3(NT)-@```!)`<9,
M`?9-B>Y(`?%,B>Y)P>X;2,'F!4P)]D2--#%,B>9)P>P"2,'F'DP)YD@)\DF)
M](GQ32'$3"'J3`GB3(ND).````!)`<1-`>)-B?1,`=)-B?))P>(%2<'L&TT)
MXD:-)!)-B>I)P>T"2<'B'DT)ZDF)]42)TDT)U4TA]4@AUDP)[DR+K"3H````
M20'%30'H38GE3`'&38G@2<'M&TG!X`5-">A&C2P&38GP2<'N`DG!X!Y-"?!-
M"<)-B<9$B<9)(=9-(>)-"?),B[0D\````$D!QDP!\4V)[DD!RDR)Z4G![AM(
MP>$%3`GQ18TT"DR)X4G![`)(P>$>3`GA38G$20G,08G*32'L32'030G@3(ND
M)/@```!)`<1,`>)-B?1)`=!,B?))P>P;2,'B!4P)XD6-)!!,B>I)P>T"2,'B
M'DP)ZD@)T4F)U4&)T$TAU4PA\4P)Z4R+K"0``0``20'%3`'N38GE2`'Q3(GF
M2<'M&TC!Y@5,">Y$C2PQ3(GV2<'N`DC!YAY,"?9)B=:)\4D)]DTAYD@ARDP)
M\DR+M"0(`0``20'&30'R38GN3`'238GJ2<'N&TG!X@5-"?)&C30238GB2<'L
M`DG!XAY-">),"=9-B=1$B=))(<Q,(>Y,">9,BZ0D$`$``$D!Q$T!X$V)]$P!
MQDV)\$G![!M)P>`%30G@1HTD!DV)Z$G![0))P>`>30GH38G51(G&30G%32'U
M22'R30GJ3(NL)!@!``!)`<5,`>E-B>5)`<I,B>%)P>T;2,'A!4P)Z46-+`I,
MB?%)P>X"2,'A'DP)\4D)R$F)SD&)RDDA]DTAX$T)\$R+M"0@`0``20'&3`'R
M38GN20'03(GJ2<'N&TC!X@5,"?)%C3003(GB2<'L`DC!XAY,">))B<Q!B=!)
M"=1-(>Q,(<%,">%,BZ0D*`$``$D!Q$P!YDV)]$@!\4R)]DG![!M(P>8%3`GF
M1(TD,4R)[DG![0)(P>8>3`GN2`GR28GUB?%-(<5,(?),">I,BZPD,`$``$D!
MQ4T!ZDV)Y4P!TDV)XDG![1M)P>(%30GJ1HTL$DV)\DG![@))P>(>30GR28GV
M1(G230G632'F2"'63`GV3(NT)#@!``!)`<9-`?!-B>Y,`<9-B>A)P>X;2<'@
M!4T)\$:--`9-B>!)P>P"2<'@'DT)X$T)PDV)Q$2)QDDAU$TAZDT)XDR+I"1`
M`0``20'$3`'A38GT20'*3(GQ2<'L&TC!X05,">%%C20*3(GI2,'A'DG![0),
M">E-B<5!B<I)"<U-(?5-(=!-">A,BZPD2`$``$D!Q4P!ZDV)Y4D!T$R)XDG!
M[1M(P>(%3`GJ18TL$$R)\DG![@)(P>(>3`GR2`G128G008G732'03"'A3`G!
M3(N$)%`!``!)`<!,`<9-B>A(`?%,B>Y)P>@;2,'F!4P)QD2-!#%,B>9)P>P"
M2(G12,'F'DP)YD&)]$@)\4PAZ4PAXD@)RDB+C"18`0``2`'!2`.$)&`!``!)
M`<I,B<%)`<=,`=)-B<)(P>$%2<'J&TP)T8G)2`'*3(GI2<'M`DC!X1Y!B=),
M">E,B=!("<Y)B<U(P>`%08G.32'E3"'&3`GN38G52<'M&TP!_DP)Z(G`2`'&
M3(G`2<'H`DC!X!Y!B?5)"<"XUL%BRDPQP3'*2(N,)&@!``!(`<%,`>%-B>Q(
M`=%,B>I)P>P;2,'B!4P)XHG22`'13(G22<'J`DC!XAY!B<Q)"=),B<)%B<!,
M,=(QUDB+E"1P`0``2`'"20'63(GB3`'V38GF2,'B!4G![AM,"?*)TDR--!9,
MB>I)P>T"3(G62,'B'D6)]T6)TDD)U4B+E"1X`0``3#'N2`'",?%,B?Y,`<)(
MP>X;2`'13(GZ2,'B!4@)\DB+M"2``0``B=)(`=%,B>)(`<9)P>P"2,'B'DP!
MUDV)ZD&)R$P)XDV)Q$6)[4DQTD4QUDZ-%#9,B<9(P>8%2<'L&TP)YHGV20'R
M3(G^2<'O`DC!YAY%B=1)"?=(B[0DB`$``$@!QDP![DF)U8G233']1#'I3(TL
M#DR)X4R)YDC![AM(P>$%2`GQ3(G&2<'H`HG)2,'F'DD!S4B+C"20`0``3`G&
M38GX23'P18GN18G_2`'!13'"2`'*3(GQ3HT$$DR)\DC!Z1M(P>(%2`G*2(GQ
MB?:)TDD!T$R)XDG![`)(P>(>18G"20G42(N4))@!``!,,>%(`<)!,<U,B=%,
M`?I)`=5,B=)(P>D;2,'B!4@)RDR)\4G![@*)TDC!X1Y)`=5(BY0DH`$``$P)
M\46)[T@!PD@!\DR)YD6)Y$@QSD$Q\$R)_DD!T$R)^DC![AM(P>(%2`GRB=))
M`=!,B=))P>H"2,'B'D6)QDD)TDB+E"2H`0``3(GV2,'N&T@!PDP!XDF)S(G)
M33'413'E3HTD*DR)\DC!X@5("?)(B[0DL`$``(G220'43(GZ2`'&2<'O`DC!
MXAY%B>5,"?I(`?%,B=9%B=)(,=9!,?!,B>Y)`<A,B>E(P>X;2,'A!4@)\8G)
M20'(3(GQ2<'N`DC!X1Y%B<=)"<Y(BXPDN`$``$R)_DC![AM(`<%,`=%)B=*)
MTDTQ\D4QU$Z-%"%,B?E(P>$%2`GQ3(GN2<'M`HG)2,'F'DD!RDB+C"3``0``
M3`GN18G42`'!2`'*3(GQ18GV2#'Q03'(3(GA20'03(GB2,'I&TC!X@5("<I(
MB?&)]HG220'03(GZ2,'B'DG![P)%B<5)"==(BY0DR`$``$PQ^4@!PD$QRDR)
MZ4P!\DC!Z1M)`=),B>I(P>(%2`G*3(GA2<'L`HG22,'A'DD!TDB+E"30`0``
M3`GA18G\18G62`'"2`'R3(G^2#'.03'P2HTT`DR)\DV)\$G!Z!M(P>(%3`G"
MB=)(`=9,B>I)P>T"2,'B'D&)\$D)U4B+E"38`0``2`'"3`'B28G,B<E-,>Q%
M,>).C2023(G"38G"2<'J&TC!X@5,"=*)TDD!U$R)\DG![@)(P>(>18GB3`GR
M3(NT).`!``!)`<9,`?%-B>Y%B>U),=9$,?9-B=9(`<Y,B=%)P>X;2,'A!4P)
M\8G)2`'.3(G!2<'H`DC!X1Y!B?9)"<A(BXPDZ`$``$@!P4D!S4B)T8G23#'!
M03',2XU,)0!-B?1-B?5)P>T;2<'D!4T)[$V)U4G!Z@))P>4>18GD30GJ3(NL
M)/`!``!,`>%!B<Q)`<5,`>I-B<5%B<!-,=5$,>Y,C2PR3(GB3(GF2,'B!4C!
M[AM("?*)TDD!U4R)\DG![@)(P>(>1(GN20G62(N4)/@!``!(`<)(`X0D``(`
M`$P!PDV)T$TQ\$0QP4F)\$@!RDB)\4G!Z!M(P>$%3`G!18G0`=%,B>))P>P"
M2,'B'DD)U$J-%`A(B<A)`=!,B?)(P>`%1`'C3#'B2(E?&$$QU4N-%"A)B<@!
MZ4G!Z!M(B4\(3`G``=!(B0=(B?!(P>X"2,'@'D@)QD$!\T0#=R!,B5\03(EW
M($B!Q!`"``!;74%<05U!7D%?PV8N#Q^$``````!!5T%6055!5%532(/L"$B%
M_P^$L0```$B+!=*%``!,BS!-A?8/A)X````/M@=)B?])B?6$P'0$/#UU53'M
M38LF387D=#)(8^U,B?,/'T0``$B)ZDR)_DR)Y_\5B80``(7`=0=!@#PL/71&
M3(MC"$B#PPA-A>1UV4B#Q`A,B>!;74%<05U!7D%?PP\?@`````!(B?T/MD4!
M2/_%A,!T!#P]=?%$*?WKEF8/'X0``````$PI\TV-9"P!2,'[`T&)70#KM68/
M'T0``$4QY.NJ#Q\`2(7_#X0W`0``059!54%454B)_5-(@>R0````@#\`=1!(
M@<20````6UU!7$%=05[#_Q4BA```28G$2(7`=.))B>5,B>?_%5:%``!(B<-(
MA<`/A,(```"`>Q,N#X20````2(GO2(/#$_\5$X0``$B)WTF)QO\5!X0``$&-
M?`8"2&/__Q6QA```28G928GHO@$```!)B<9(B<<QP$C'PO____](C0U\)0``
M_Q5JA0``OP$```!,B>I,B?;_%9&#``!,B?>#^/]T$(M$)!@E`/```#T`0```
M=''_%3.#``!,B??_%1J#``#I5O___P\?1```#[9#%(7`#X1%____@_@N#X5;
M____@'L5``^$,O___^E,____#Q]``$R)Y_\5KX,``$B)[_\53H,``$B!Q)``
M``!;74%<05U!7L-F#Q]$``###Q^``````.BS_O__ZXZ054B)_DB)_;\!````
M2('LD````$B)XO\5;(0``(7`=4"+5"08@>(`\```@?H`0```=`B!^@"@``!U
M*$B)[[X"````_Q4@A```A<`/E,!(@<20````#[;`7<,/'X``````,<!(@<20
M````7<,/'T0``$%6NO\/``!!54%428GT54B)_4B-/5$D``!(@>P($```28GE
M3(GN_Q5$@@``A<!^8(U0_TQC\D*`/#0`#X5_````A=)T2TR)\KXO````3(GO
M_Q72@@``2(7`=#5(BP5V@@``BSC_%0:#``!,B?%,B>I(B>Y(B<?_%8R#``!(
M@<0($```74%<05U!7L,/'T0``$B+!4&"``"+./\5T8(``$R)XDB)[DB)Q_\5
M0H(``$B!Q`@0``!=05Q!74%>PP\?`$QC\.N`9BX/'X0``````)!!5S'`059!
M54%454B)]5-(B?M(@^PH@#X]#Y3`2`'%2(GO_Q7(@0``2(UT)!Q(B=])B<0Q
MP.AF_/__2(7`#X3]````28G%2(G'_Q6A@0``23G$#X:X````3&-T)!Q,BSTL
M@@``2<'F`P^V`X3`#X25`0``/#T/A(T!``!(B=AFD`^V4`%(_\"$TG0%@/H]
M=?!(*=A(F$T#-TJ-?"`"_Q4%@@``28D&2(7`=%5)BP=(8U0D'$B-2P%(BQ30
M#[8#B`*$P'0?/#UU#.L99@\?1```A,!T#P^V`4C_PDC_P8@"/#UU[<8"/3'`
M#Q^$```````/MDP%`(A,`@%(_\"$R77P2(/$*%M=05Q!74%>05_#D#'`9@\?
M1```#[94!0!!B%0%`$C_P(32=>](@\0H6UU!7$%=05Y!7\,/'X0``````$R+
M/4F!``!-BP=)@S@`#X2[````3(G`13'M9@\?1```2(/`"$2)ZD'_Q4B#.`!U
M\(UR`TAC]DC!Y@.+!5"2``"%P'5<3(E$)`A(B??'!3J2```!````_Q4,@0``
M2(7`#X1;____3(M$)`A-8_5(B<=)P>8#3(GR3(G&_Q5(@0``28D'2(G!08U%
M`4B82,<$P0````!$B6PD'.F*_O__9I!,B<?_%0^!``!)B0=(B<%(A<`/A`C_
M__]-8_5)P>8#Z\4/'X``````,<#IAO[__[X0````13'MZ5[___\/'T``2(/L
M"$B+!=U_``"+./\5;8```$B+%7Y_``!(@\0(2(T-4V$``$B)QTB--5HA``#_
M)6N```!F+@\?A```````D%-(BQV@?P``BSO_%3"```!(B<=GZ*?___^+._\5
M'X```$R-!>$B``!%,<E;2(T5[14``$B)QTR)P4B--24A``#_)4J```!F+@\?
MA```````05154TB!["`@``#_%>]^``!(B>5,C:0D$!```$R-#=(@``!!B<!(
MC0W](```2(GO,<"Z`1```+X!````_Q66@```N@`0``!,B>9(B>__%9U^``!%
M,<"%P'@PC7@!2(G#2&/__Q6/?P``28G`2(7`=!E(8]M,B>9(B<=(B=K_%35_
M``#&!!@`28G`2('$("```$R)P%M=05S##Q^``````.E;____D&8N#Q^$````
M``!!5S'`059)B?9!54%454B)_4B-/7`@``!32('LF!```$R-I"20````3(GF
MZ!#Y__^^+P```$B)[TB)P_\57WX``$B%P'0J,<!(B>Y(C3T_(```Z$G\__](
MB>A(@<28$```6UU!7$%=05Y!7\,/'T``2(GO_Q47?@``2(TU'B```$R)]T&)
MQ?\51'\``$F)QTB%P'2R08`_`$R--><?```/A-8````/'P!(A=MT%$R)_DB)
MW_\55WX``(7`#X25````3(G__Q7&?0``C5#_B<%(8\),`?B`."]U&&8/'T0`
M`(G1_\K&``!(8\),`?B`."]T[D*-1"D!/?\/```/CT3___](@^P(2(T-LB``
M`$V)^#'`54R-#88?``"Z`!```$R)Y[X!````_Q7[?@``3(GFOP$```!(C50D
M$/\5('T``%I9A<!U$(M$)!@E`/```#T`@```=$I(C35!'P``,?__%6M^``!)
MB<=(A<`/A-7^__]!@#\`#X4M____2(7;=`6`.RYT$TV)][D!````Z6#___]F
M#Q]$``"`>P$`=+CKY;X!````3(GG_Q4:?@``A<!UI$R)YDB-/=4>``#HW_K_
M_TR)Y_\5'GT``.F+_O__D`^V!TF)^(3`=!9F#Q]$``!(_\<\+P^V!TP/1,>$
MP'7P3(G`PV8N#Q^$``````!FD%5(A?\/A)X```"`/P!(B?T/A)(```#_%71\
M``!(C50%_T@YU7(6Z9<````/'T0``$C_RD@YU0^$E````(`Z+W3O2#G5<A+K
M>@\?A```````2/_*2#G5='B`.B]U\T@YU74+ZT0/'T``@#HO=0A(_\I(.=5R
M\T@IZDB-0@)(/0`0``!W9$B)[DC_PKD`$```2(T]VGT``/\5Y'P``$B-!<U]
M``!=PP\?`+\"````_Q65?```2(7`=#"Z+@```&:)$%W#2#G5=:9F#Q^$````
M``"`?0`O=-)(C3W#'0``7?\E!'P```\?0``QP%W##Q]``%4QP%-(C1VG'0``
M2(/L2&8/;P5970``9HE$)#!(C6PD#`\11"009@]O!5)=```/$40D(`\?1```
M,<!(B>Y(B=_H"_;__TB%P'0^2(L%[WL``$AC5"0,2(L`2(T$T$B+4`A(B1!(
MA=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C1TL'0``D#'`
M2(GN2(G?Z+/U__](A<!T/DB+!9=[``!(8U0D#$B+`$B-!-!(BU`(2(D02(72
M=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(T=W!P``&8/'X0`
M`````#'`2(GN2(G?Z%/U__](A<!T/DB+!3=[``!(8U0D#$B+`$B-!-!(BU`(
M2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(T=A1P`
M`&8/'X0``````#'`2(GN2(G?Z//T__](A<!T/DB+!==Z``!(8U0D#$B+`$B-
M!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```
M2(T=+!P``&8/'X0``````#'`2(GN2(G?Z)/T__](A<!T/DB+!7=Z``!(8U0D
M#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV
M9@\?1```2(T=W!L``&8/'X0``````#'`2(GN2(G?Z#/T__](A<!T/DB+!1=Z
M``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(
MA=)U\.NV9@\?1```2(T=,1L``&8/'X0``````#'`2(GN2(G?Z-/S__](A<!T
M/DB+!;=Y``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#
MP`A(B1!(A=)U\.NV9@\?1```2(T=*!L``&8/'X0``````#'`2(GN2(G?Z'/S
M__](A<!T/DB+!5=Y``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````
M2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(T=TAH``&8/'X0``````#'`2(GN
M2(G?Z!/S__](A<!T/DB+!?=X``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/
M'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(T=?!H``&8/'X0`````
M`#'`2(GN2(G?Z+/R__](A<!T/DB+!9=X``!(8U0D#$B+`$B-!-!(BU`(2(D0
M2(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(T=NAD``&8/
M'X0``````#'`2(GN2(G?Z%/R__](A<!T/DB+!3=X``!(8U0D#$B+`$B-!-!(
MBU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(T=
MQAD``&8/'X0``````#'`2(GN2(G?Z//Q__](A<!T/DB+!==W``!(8U0D#$B+
M`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?
M1```2(T=;QD``&8/'X0``````#'`2(GN2(G?Z)/Q__](A<!T/DB+!7=W``!(
M8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U
M\.NV9@\?1```2(GN2(T]%QD``.A!\?__2(G&2(7`=`Y(C3W;&```,<#HB_3_
M_TB)[DB-/0,9```QP.@:\?__2(G&2(7`=`Y(C3W_&```,<#H9/3__TB)[DB-
M/?D8```QP.CS\/__2(G&2(7`="I(C3TL&```,<#H/?3__TB--0$9``!(C3U2
M&```,<#H*/3__TB#Q$A;7<-(B>Y(C3W&&```,<#HL/#__TB)QDB%P'002(T]
M0!@``#'`Z/KS___KNTBX4$%27T-,14%(.40D(76J9H%\)"E./76A2(UT)"OK
MSP\?@`````"+!6IW``"#^/]T!<,/'T``2(/L&$B-/?07```QP$B-="0,Z$GP
M__](B<(QP$B%TG02#[82@/HP#Y7!,<"$T@^5P"'(B04G=P``2(/$&,-FD$B#
M[`C_%6YU``")Q_\51G4``$B%P'0#2(L`2(/$",.005=(C04Q&```2(T5'1@`
M`$%69D@/;LAF2`]NPDB-!1(8``!!568/;,%(C0T`&```9D@/;M!!5$B-!0D8
M``!)B?Q,C37O%P``55-(@^Q8#Q%$)!AF2`]NP4B-;"083(UL)`QF#VS"2(E$
M)#A(QT0D0``````/$40D*.L@#Q]$``!(B<?_%4]V``!(A<!T4DR+=0!(@\4(
M387V=#1,B>Y,B?<QP.A8[___3(GF2(G#2(7`=`6`.`!UR$R)]S'`2(/%".B:
M\O__3(MU^$V%]G7,2(/$6%M=05Q!74%>05_#9I!,B>?_%6=T``!(B=])B<?_
M%5MT``!)C7P'`O\5"'4``$B#[`A-B>"^`0```%-)B<=(Q\+_____2(G'3(T-
M/18``$B-#5<7```QP/\5N'4``#'`3(G^3(GWZ"/R__]86NE*____9BX/'X0`
M`````&:005=(C04%%P``059!54F)_4B-/>$5``!!5%532('L:($``$B)1"1`
M2(T%R!4``$B-G"1@`0``2(E$)$A(B=Y(C058%@``2(F$)+@```!(C06_%@``
M2(F$),````!(C057%@``2(F$),@```!(C06I%@``2(F$)-````!(C06>%@``
M2(E$)&@QP$C'1"10`````$C'A"38`````````$C'1"1P`````.@%[O__2(7`
M=`R`.`!(B<4/A:P$```QP&?HS/W__TB)Q4B%P`^$\`,``$B)[_\5)W,``$B-
M?``!_Q74<P``1`^V10!)B<1%A,!T/DV)YTR--2T6```/'T0``$C_Q44/ML!,
MB?],B?%(Q\+_____O@$````QP$F#QP+_%7-T``!$#[9%`$6$P'713(VT)+``
M``!(C3UF%0``ZQ%)BWX(28/&"$B%_P^$+P$``$B)WC'`Z%7M__](B<5(A<!T
MW8`X`'382(G'Z&#O__^%P'3,2(GO_Q7;<@``28G`2(7`#X3W````#Q^`````
M`$R)!"1,B<?_%6-R``!,B>=(B<7_%5=R``!$C;P%!`0``$UC_TR)__\5^W(`
M`$%43(T-2A0``$B-#6`5``!(B<5(C05?%0``2,?"_____[X!````4$B)[TR+
M1"00,<#_%:1S``"^P`$``$B)[_\5IG$``$%805F#^/]U$_\5=W$``$2+"$&#
M^1$/A1@#``!(B=I(B>Z_`0```/\5*7,``$&)QH7`#X2F````28M-`$F)Z+X!
M````13'D2(L%0',``$B-%8D5``!(BS@QP/\5#G,``$B!Q&B!``!,B>!;74%<
M05U!7D%?PV8/'X0``````$B+;"1`13'VZQ-F#Q]$``!)8\9(BVS$0$B%[70[
M@'T``'0U2(GO0?_&Z"+N__^%P'3>2(GO_Q6=<0``28G`2(7`#X7)_O__26/&
M2(MLQ$!(A>UUR0\?0`!%,<#IL/[__XN$)'@!```E`/```#T`0```#X5#____
M1(ND)'P!``#_%0-Q``!!.<0/A2S___^+A"1X`0``)?\!```]P`$```^%%?__
M_TR)__\5BG$``$B-/:L3``!(B=Y)B<0QP.ANZ___2(G'2(7`#X1"`@``_Q4$
M<0``28M]`$B)QF?H#_+__TF)QTB%P`^$(P(``$R)__\5BG```(/X`WX]2&/0
MN04```!(C3VQ$P``28UT%_SSI@^7PH#:`(32=1V#^`0/A*D%``"#Z`5(F$&`
M/`<O#X29!0``#Q]``#'`9^B`^O__A<!U%C'V3(G__Q5!<0``B00DA<`/A;\!
M``!(C37Z$@``2(T]9Q(``#'`Z"'N__](C1V#$P``3(TM$Q(``/\5O6\``%-(
MQ\+_____28GH4$R-#?H1``"^`0```$R)YTB-#2\3```QP/\5:W$``%A:ZTL/
M'X``````_Q5*;P``@S@1=4S_%7=O``!!_\9(@^P(38GI4TF)Z$B-#003``"^
M`0```$%62,?"_____TR)YU`QP/\5('$``$B#Q""^P`$``$R)Y_\5'F\``(/X
M_W2I2(GO_Q7H;@``3(GF2(T]5A$``#'`Z&?M__],B>=GZ/[Y___IJ_W__V8/
M'X0``````$B-/3L2``!%,>3K$0\?0`!)8\1(BWS$8$B%_W0Y2(G>,<!!_\3H
MQNG__TB%P'3A@#@`=-Q(B<?_%5MO``!(B<5(A<`/A<?[__])8\1(BWS$8$B%
M_W7'OPT```!(C2WE$0``_Q60;P``0;A3````28G$Z;O[__])BTT`28GHO@$`
M``!%,>1(BP5$<```2(T531(``$B+.#'`_Q42<```Z?_\__\/'T0``$B)QV?H
M/_G__TB!Q&B!``!(B>];74%<05U!7D%?_R7-;@``#Q]$``!-BWT`Z=3]__]!
MB<>Z`@```$C'QN[___^)Q_\5N&\``+H&````2(G>1(G__Q6O;@``@+PD8`$`
M``!U#H"\)&$!``!##X0=!```BSPD,=(Q]DR-M"3@````_Q5Z;P``9@]O!?I/
M``!(C80D&`$``$C'A"00`0```````,>$)%@!````````#RF$).````!F#V\%
MVT\``$B)1"08#RF$)/````!F#V\%UD\```\IA"0``0``9@\?1```BSPDN@"`
M``!(B=[_%1=N``!(B<%!B<"%P`^.90$``$B+O"0(`0``2(N4)!`!``!(8\%)
MB=^--,](.?Y(B;0D"`$``$B#T@!(P>@=2`'02&.4)%@!``!(B80D$`$``(72
M#X6R````08/X/P^.V`(``$&-0,")1"04P>@&1(UH`8E$)`A)P>4&30']9@\?
M1```\T$/;P_S00]O5Q!,B?=)@\=`\T$/;U_@\T$/;V?P#Q&,)!@!```/$90D
M*`$```\1G"0X`0``#Q&D)$@!``#HM='__TTY[W6XBT0D"$2+1"04P>`&02G`
M1(E$)`A)8]!(BWPD&$R)[KE(````_Q5&;0``1(M$)`A$B80D6`$``.GL_O__
M#Q]``$&Y0````$B+1"082(E,)`A(B=Y!*=%$.<E(C3P01`].R4UC^4R)^O\5
MZVP``(N$)%@!``!(BTPD"$0!^(/X0(F$)%@!```/A9S^__]!B<A,B?=%*?A)
M`=]$B40D".@.T?__1(M$)`CIXO[__XL\)/\5<VP``$B+A"0(`0``BYPD"`$`
M`$2+K"00`0``2,'H`P_+@^`_00_-C5`!2)C&A`08`0``@(/Z.`^.B@$``+E`
M````2&/R2`-T)!@IT70.,<")PO_`Q@06`#G(<O1,B??HF]#__V8/[\!(QX0D
M2`$````````/$80D&`$```\1A"0H`0``#Q&$)#@!``!,B?=$B:PD4`$``$R-
M?"0@3(VT)*@```")G"14`0``3(TMI0X``.A(T/__BX0DX`````_(B40D((N$
M).@````/R(E$)"2+A"3P````#\B)1"0HBX0D^`````_(B40D+(N$)``!```/
MR(E$)#!(C80D@````$B)!"1(B<,/'X0``````$B)WTB#PP)%#[8'3(GI2,?"
M_____[X!````,<!)_\?_%9-L``!).=YUUDB-!6@.``#&A"2H`````%#_="0(
M2(T-(`X``$F)Z$R)YS'`O@$```!,C0W7#```2,?"______\54FP``%E>Z4+[
M__]-BVT(387M#X1>^O__3(GO_Q6=:@``2(/X`P^&2_K__TF-=`7\N04```!(
MC3W"#0``\Z8/E\`<`(3`30]$_>DH^O__38G]Z9?]__^X.````"G02&/22`-4
M)!B#^`AS+*@$#X6\````A<`/A*'^___&`@"H`@^$EO[__S'_9HE\`O[IBO[_
M_P\?1```B<%(B==(QT0*^`````"-2/\QP,'I`_-(J^EG_O__@+PD8@$``$$/
MA=7[__^`O"1C`0``0P^%Q_O__X"\)&0!``!(#X6Y^___@+PD90$``$4/A:O[
M__]$BSPDN@(```!(Q\;&____1(G__Q4A:P``NBD```!(B=Y$B?__%1AJ``!(
MC04:#0``4%/IN/[__V8N#Q^$``````#'`@````#'1`+\`````.G:_?__9BX/
M'X0```````\?`$%7059!54%455-(@^PH3(LE<VD``$R-?"0<08L\)/\5_&D`
M`$&+/"1(B</_%>]I```/MI.X````3(G^2(T]80L``(B0N0```#'`Z-'C__](
MA<!T"8`X,0^$TP(``#'`9^AK[?__08L\)/\5L6D``+D+````N@$```!(C35C
M#```2(G'_Q5O:0``2(7`#X3'````2(M`$(,]PWH```%,BW`H#XZR````,=OK
M-0\?1```2(MV$$B+%9UZ``!)8\5(BSS"_Q4H:0``08G`BP6/>@``187`=7B#
MQ0)$B>LYQ7UN08L\)(G=1(UK`?\5,&D``#')2&/33(GV2(G'_Q67:0``2(7`
M=$)(BS"+1@PE``0@`#T`!```=)A(B70D"$&+/"3_%?EH``!(BW0D"+D"````
M,=)(B<?_%6QH``!(B<;I</___P\?0`"+!1)Z``"-4/\YV@^$9P$``$&+/"3_
M%;UH``"Y`P```+H!````2(TU=`L``$B)Q_\5>V@``$B)PTB%P'0U2(M`$$&+
M/"1(BRC_%8IH``!(C15-"P``2(G'2(GN_Q7W9P``2(M#$$B+*/9%#D`/A;$!
M``!!BSPD_Q5<:```N0,```"Z`0```$B--1H*``!(B<?_%1IH``!(B<-(A<!T
M/4R)_DB-/8$)```QP.@IXO__28G%2(7`#X0]`0``2(M#$$&+/"1(BRC_%0QH
M``!,B>I(B<=(B>[_%7UG``!!BSPD_Q7S9P``N@$```!(C36V"@``2(G'_Q7N
M9P``08L\)$B)Q?\5T6<``$B-%:X*``!(B>Y(B<?_%3YG``!!BSPD_Q6T9P``
M2(T]]0@``$R)_L:`N0`````QP.B<X?__2(D%W7@``$B)QTB%P'1EOL`!``#_
M%7IF``"-4`&#^@%V"8/X$0^%UP```$B#Q"A;74%<05U!7D%?PV:0@_@!#XZ0
M_O__NP$```!FD$&+/"3_P_\51&<``$R)]DB)Q_\50&8``#D=<G@``'_@Z63^
M__\/'P!(BSU9>```9^AK\O__2(D%7'@``$B)QTB%P`^%>____TB-/8D*```Q
MP/\5$6<``&8/'X0``````(!X`0`/A"O]___I'OW__Y!(BP41>```08L\)$R+
M*$B+0Q!(BRC_%<5F``!,B>Y(B>_H2N/__^FX_O__08L\)/\5JV8``$B)[DB)
MQ_\5UV8``.DT_O__B<%(BP7)=P``2(L5TG<``$B-/3,*``!(BS`QP/\5D&8`
M``\?A```````54B)_5-(@^P(9^@AZ?__2(G'9^CHZ/__2(G#,<!GZ-WO__^%
MP'0E2(7M=""`?0``=!JY!````$B-/;@(``!(B=[SI@^7P!P`A,!T#$B#Q`A;
M7<,/'T0``$B#Q`A(B>];7>G:X/__9BX/'X0``````$B-!?%F``!(A<!T#$B+
M#>5F``#I^,;__S')Z_</'T``\\-F9F9F9BX/'X0``````$B);"383(ED).!(
MC2TO8@``3(TE(&(``$R);"3H3(ET)/!,B7PD^$B)7"302(/L.$PIY4&)_4F)
M]DC!_0-)B=?H>\;__TB%[70<,=L/'T``3(GZ3(GV1(GO0?\4W$B#PP%(.>MR
MZDB+7"0(2(ML)!!,BV0D&$R+;"0@3(MT)"A,BWPD,$B#Q#C#````2(/L"$B#
MQ`C#````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`E<R\E<P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R.CIB
M;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO
M)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?05)'0P!005)?
M05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%2
M7U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?
M0TQ%04X]`#$`3$E"4$%42`!$64Q$7TQ)0E)!4EE?4$%42`!32$Q)0E]0051(
M`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>``E
M<R5S)7,E<P!P87(M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M
M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`4$%2.CI086-K
M97(Z.E9%4E-)3TX`,2XP,S8`+64`+2T`)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S
M.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R
M96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!5;F%B
M;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@``````````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M
M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M
M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O
M9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL
M97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U
M8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M
M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU3
M5VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@
M/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*
M<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W
M,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N
M("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M
M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R
M9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)
M3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE
M>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I
M('L*0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.
M5GM005)?05)'0WT@+2`Q*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L
M<V4@>PIF;W(@*&ME>7,@)45.5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY0
M05)?05)'5E\O.PI]"GT*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-
M4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@
M(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S
M971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O
M<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![
M?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H
M7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O
M9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E
M="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F
M<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@
M)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE
M('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N
M<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP
M;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@
M?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T
M('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@
M7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(
M+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@
M)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U
M:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM
M>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D
M9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH
M6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L
M("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\
M<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R
M8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@
M/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@
M>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D
M8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS
M92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^
M("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F
M+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE
M*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY
M("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\
M(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2![
M"FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0[
M"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y
M*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL
M96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?
M=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F
M:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*
M?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M
M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G
M/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D
M(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A
M<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.
M0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL
M93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?
M;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N
M86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O
M:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*
M?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL
M97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@
M7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@
M)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D55
M4T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B
M;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A
M)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F
M('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R
M"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P
M87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E
M<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]21553
M17T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA
M=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP
M72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H
M)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G
M*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G
M*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@
M/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L
M;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF
M("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B
M6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G
M*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@
M)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0
M)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D
M9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'
M5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D
M<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H
M)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G
M)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A
M;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD
M;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,[
M"B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D
M+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P
M87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R
M(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP
M,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?
M5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@
M/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A
M9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W
M+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T
M(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD
M=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC
M(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@
M(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA
M9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@
M+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*
M)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D[
M"G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.
M+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[
M)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L
M=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E
M>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@
M>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2![
M"FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F
M:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C
M72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]
M"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H
M;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B
M)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO
M="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q
M*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL
M92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2![
M"B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L
M("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I
M;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN
M*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q
M*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F
M:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^
M<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U
M=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH
M)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I
M.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A
M)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@
M>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S
M=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N
M(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D
M<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS
M.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE
M;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB
M:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*
M?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M
M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN
M(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H
M*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@
M9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A
M.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0
M?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@
M8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z
M:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[
M"FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG
M.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN
M86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*
M;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?
M5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M
M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q
M*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*
M979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R
M.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S
M="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!]
M.PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L
M87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T
M96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]
M"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-
M4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0
M("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M
M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED
M.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^
M.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R
M;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P
M=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M
M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<[
M"GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T
M:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@
M*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS
M>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B
M*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*
M)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M
M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!
M.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@
M;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P
M<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N
M9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^
M:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*
M)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\[
M"GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D
M92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N
M;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA
M;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C
M86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT
M("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP
M;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L
M;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA
M;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I
M('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%
M3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%
M35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE
M?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N
M9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T
M<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*
M)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD
M969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I
M;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@
M*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O
M;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF
M;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!
M4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.
M5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]4
M14U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI
M<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B
M<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM0
M05)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI
M+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F
M:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<
M;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`
M24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q
M=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E
M>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA
M:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A
M<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N
M)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE
M(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O
M9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF
M("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/
M4CL*,3L*7U]%3D1?7PH``````'!E<FQX<VDN8P```````````````````/__
M__\`````_____P````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(`$C16<`````B:O-[P````#^W+J8`````'94,A``````\.'2PP``````````
M``````$;`SO<````&@```)!____X````P'___R`!``#0?___0`8``+""__\X
M`0``D)C__X0!``!@F?__T`$``+":__\\`@``()O__V@"``#PF___N`(``!">
M__\<`P``4)[__S0#``"@GO__4`,``$"?__^$`P``4)___Y@#```@H?__^`,`
M`%"A__\,!```0*+__S@$```@J/__9`0``'"H__]\!```D*C__Y0$``#@J?__
M\`0``'"T___`!0``(+C__PP&``"0N/__<`8``+"X__^(!@``P+C__YP&````
M````%``````````!>E(``7@0`1L,!PB0`0``)````!P```"0?O__,``````.
M$$8.&$H/"W<(@``_&CLJ,R0B`````!0```!$````F'[__P@`````````````
M`$@```!<````<('__]85````0@X0CP)&#AB.`T(.((T$0@XHC`5!#C"&!D$.
M.(,'1P[(!`.V%0XX00XP00XH0@X@0@X80@X00@X(``!(````J`````27___-
M`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)M"@XX1`XP
M00XH0@X@0@X80@X00@X(2`L`:````/0```"(E___3P$```!+#A".`D(.&(T#
M0@X@C`1!#BB&!40.,(,&1P[``4P*#C!!#BA!#B!"#AA"#A!"#@A!"P,!`0XP
M00XH00X@0@X80@X00@X(1\/&S,W.2`[``8,&A@6,!(T#C@(`*````&`!``!L
MF/__:P````!!#A"&`E(.H`$"00H.$$0."$@+20X000X(``!,````C`$``+"8
M___%`````$(.$(X"1PX8C0-"#B",!$0.*(8%40ZP(`)C"@XH00X@0@X80@X0
M0@X(1@ME"@XH00X@0@X80@X00@X(1`L``&````#<`0``,)G__QP"````0@X0
MCP)$#AB.`T(.((T$0@XHC`5!#C"&!D0..(,'1PY@`NX*#CA!#C!!#BA"#B!"
M#AA"#A!"#@A""UT*#CA!#C!!#BA"#B!"#AA"#A!"#@A)"P`4````0`(``.R:
M__\U`````$0.$%H."``8````6`(``!2;__]&`````$$.$(,":PX(````,```
M`'0"``!(F___F0````!"#A",`D$.&(8#00X@@P1'#L!``H8.($0.&$$.$$(.
M"````!````"H`@``M)O__P8`````````7````+P"``"PF___SP$```!"#A"/
M`D0.&(X#10X@C01"#BB,!4$.,(8&2PXX@P='#M`A`D$*#CA!#C!!#BA"#B!"
M#AA"#A!"#@A%"P*6#M@A30[@(6X.V"%!#M`A````$````!P#```@G?__)```
M```````H````,`,``#R=___L`````$$.$(8"`J,*#@A$"UD*#@A!"UP*#@A*
M"T,.""@```!<`P```)[__]D%````00X0A@)##AB#`TL.8`-]!0H.&$$.$$$.
M"$$+%````(@#``"TH___3@````!4#B!Y#@@`%````*`#``#LH___'P````!$
M#A!:#@@`6````+@#``#TH___1`$```!"#A"/`E`.&(X#4PX@C012#BB,!5(.
M,(8&00XX@P=$#I`!`H4*#CA!#C!!#BA"#B!"#AA"#A!"#@A#"V0.F`%)#J`!
M<0Z8`4$.D`',````%`0``.BD__^#"@```$(.$(\"20X8C@-"#B"-!$P.*(P%
M00XPA@9!#CB#!T<.H(,"`YT!#JB#`F4.L(,"8`ZH@P)"#J"#`@)C"@XX1`XP
M00XH0@X@0@X80@X00@X(2@L#A`$.J(,"2PZP@P)?#JB#`D$.H(,"80ZH@P)$
M#K"#`E$.N(,"2P[`@P),#J"#`@+\"@XX1`XP00XH0@X@0@X80@X00@X(2PL#
MB@,.J(,"1`ZP@P)I#JB#`D$.H(,"`Q@!"@ZH@P)!#K"#`D\+2````.0$``"H
MKO__J`,```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=$#F`#I0(*
M#CA!#C!!#BA"#B!"#AA"#A!"#@A#"S`````P!0``#++__V8`````00X0A@)$
M#AB#`T0.(`)'"@X800X000X(1@M$#AA$#A!!#@@L````9`4``(AY__\!`@``
M`$(.$(P"00X8A@-$#E`#8P$*#AA$#A!"#@A!"P`````4````E`4``!BR__\<
M```````````````0````K`4``""R__\"`````````"0```#`!0``'++__XD`
M````48P%A@9?#D"#!X\"C@.-!`)8#@@`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"0S````````\C(````````!````````
M`!X#`````````0`````````I`P````````$`````````.0,````````/````
M`````)$$````````#```````````,`````````T`````````S&D````````9
M`````````'C+````````&P`````````(`````````!H`````````@,L`````
M```<``````````@`````````!`````````#H`@```````/7^_V\`````@`<`
M```````%`````````#@2````````!@````````#P"`````````H`````````
M_`8````````+`````````!@`````````%0````````````````````,`````
M````N,T````````"`````````#``````````%``````````'`````````!<`
M````````("$````````'`````````&`:````````"`````````#`!@``````
M``D`````````&``````````8````````````````````^___;P`````!```(
M`````/[__V\``````!H```````#___]O``````(`````````\/__;P`````T
M&0```````/G__V\`````!```````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(C+`````````````````````````````"8P````````
M-C``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T````````/____\`````"',```````!'
M0T,Z("A'3E4I(#0N-"XW(#(P,3(P,S$S("A2960@2&%T(#0N-"XW+3(S*0!'
M0T,Z("A'3E4I(#$P+C,N,```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))
M+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N
M9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YP;'0N
M9V]T`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A
M;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F1A=&$`+F)S
M<P`N8V]M;65N=```````````````````````````````````````````````
M````````````````````````````````````````````````"P````$````"
M`````````*@"````````J`(````````<`````````````````````0``````
M`````````````!,````'`````@````````#$`@```````,0"````````(```
M``````````````````0````````````````````E````!0````(`````````
MZ`(```````#H`@```````)@$````````!0`````````(``````````0`````
M````(0```/;__V\"`````````(`'````````@`<```````!L`0````````4`
M````````"````````````````````"L````+`````@````````#P"```````
M`/`(````````2`D````````&`````0````@`````````&``````````S````
M`P````(`````````.!(````````X$@```````/P&```````````````````!
M````````````````````.P```/___V\"`````````#09````````-!D`````
M``#&``````````4``````````@`````````"`````````$@```#^__]O`@``
M````````&@`````````:````````8``````````&`````@````@`````````
M``````````!7````!`````(`````````8!H```````!@&@```````,`&````
M````!0`````````(`````````!@`````````80````0```!"`````````"`A
M````````("$````````P``````````4````6````"``````````8````````
M`&L````!````!@``````````,``````````P````````#@``````````````
M``````0```````````````````!F`````0````8`````````$#`````````0
M,````````#`````````````````````0`````````!``````````<0````$`
M```&`````````$`P````````0#`````````(````````````````````"```
M```````(`````````'H````!````!@````````!0,````````%`P````````
M>3D``````````````````!````````````````````"``````0````8`````
M````S&D```````#,:0````````D````````````````````$````````````
M````````A@````$````"``````````!P`````````'````````"`0```````
M````````````$````````````````````(X````!`````@````````"`L```
M`````("P````````W`````````````````````0```````````````````"<
M`````0````(`````````8+$```````!@L0```````.@%````````````````
M```(````````````````````I@````X````#`````````'C+````````>+L`
M```````(````````````````````"``````````(`````````+(````/````
M`P````````"`RP```````("[````````"`````````````````````@`````
M````"`````````"^````!@````,`````````B,L```````"(NP```````#`"
M````````!@`````````(`````````!``````````=0````$````#````````
M`+C-````````N+T```````!(`@``````````````````"``````````(````
M`````,<````!`````P``````````T`````````#`````````(```````````
M``````````@```````````````````#-````"`````,`````````(-``````
M```@P````````$@0```````````````````@````````````````````T@``
M``$````P````````````````````(,`````````_````````````````````
M`0`````````!``````````$````#`````````````````````````%_`````
C````VP````````````````````$`````````````````````
